@@ -1,3 +1,14 @@
+"""
+    domonic.components
+    ====================================
+
+    A bit of a dumping ground for components ideas.
+
+    Mainly used by the examples.
+
+"""
+
+
 import base64
 import json
 
@@ -37,8 +48,8 @@ class Websocket(object):
         elif event_string == 'mousedown' or event_string == 'mouseup' or event_string == "mousemove":
             evt = MouseEvent(event_string)
             evt.initMouseEvent(_type=event_string, screenX=dom_event['screenX'], screenY=dom_event['screenY'],
-                            clientX=dom_event['clientX'], clientY=dom_event['clientY'],
-                            ctrlKey=dom_event['ctrlKey'], altKey=dom_event['altKey'], shiftKey=dom_event['shiftKey'])
+                               clientX=dom_event['clientX'], clientY=dom_event['clientY'],
+                               ctrlKey=dom_event['ctrlKey'], altKey=dom_event['altKey'], shiftKey=dom_event['shiftKey'])
 
         elif event_string in ["drag", "dragend", "dragenter", "dragexit", "dragleave", "dragover", "dragstart", "drop"]:
             evt = DragEvent(event_string)
@@ -71,12 +82,12 @@ class Websocket(object):
         return evt
 
     def __init__(self, reference='socket', address='ws://0.0.0.0:5555', target="body",
-                    mouse_events=True, keyboard_events=True,
-                    ui_events=False, focus_events=False, touch_events=False, wheel_events=False,
-                    animation_events=False, clipboard_events=False, error_events=False, submit_events=False,
-                    pointer_events=False, before_unload_events=False, SVG_events=False, timer_events=False,
-                    drag_events=False, hashchange_events=False, input_events=False, page_transition_events=False,
-                    popstate_events=False, storage_events=False, transition_events=False, progress_events=False):
+                 mouse_events=True, keyboard_events=True,
+                 ui_events=False, focus_events=False, touch_events=False, wheel_events=False,
+                 animation_events=False, clipboard_events=False, error_events=False, submit_events=False,
+                 pointer_events=False, before_unload_events=False, SVG_events=False, timer_events=False,
+                 drag_events=False, hashchange_events=False, input_events=False, page_transition_events=False,
+                 popstate_events=False, storage_events=False, transition_events=False, progress_events=False):
 
         self.reference = reference
         self.address = address
@@ -398,8 +409,7 @@ class Sound(object):
         return str(
             div(
                 audio(source(_src=self.filename, _type="audio/mp3"), _id="sfx", _autoplay="true"),
-                script(
-                """
+                script("""
                 function play_sound( filename ) {
                 let sound = document.getElementById("sfx");
                 sound.currentTime = 0;
@@ -578,3 +588,41 @@ class Webpage(object):  # TODO - shouldn't this extend html?
                 body(div(self.content, _class="domonic-container"))
             )
         )
+
+# quick templates
+
+
+webpage_tmpl = lambda content: f"""
+    <!DOCTYPE html>
+    <html>
+    <head>
+    <meta charset="utf-8">
+    <title>webpage</title>
+    </head>
+    <body>
+    {content}
+    </body>
+    </html>
+    """
+
+# carousel_tmpl = lambda content: f"""
+#     <div class="carousel slide" data-ride="carousel">
+#         <div class="carousel-inner">
+#             {content}
+#         </div>
+#         <a class="left carousel-control" href="#myCarousel" role="button" data-slide="prev">
+#             <span class="glyphicon glyphicon-chevron-left" aria-hidden="true"></span>
+#             <span class="sr-only">Previous</span>
+#         </a>
+#         <a class="right carousel-control" href="#myCarousel" role="button" data-slide="next">
+#             <span class="glyphicon glyphicon-chevron-right" aria-hidden="true"></span>
+#             <span class="sr-only">Next</span>
+#         </a>
+#     </div>
+#     """
+
+# item_tmpl = lambda content: f"""
+#     <div class="item">
+#         {content}
+#     </div>
+#     """
