@@ -49,7 +49,7 @@ html_attributes = [
             ]
 
 
-def render(inp, outp=''):
+def render(inp, outp='', to=None):  # doctype='html5')
     """render
 
     Renders the input to string or to a file.
@@ -57,10 +57,17 @@ def render(inp, outp=''):
     Args:
         inp (obj): A domonic tag. For example div()
         outp (str): An optional output filename
+        to (str): An optional output type. if 'pyml' is specified then pyml is returned instead of html.
 
     Returns:
         str: A HTML rendered string
     """
+    if to == 'pyml':
+        if outp != '':
+            with open(outp, "w+") as f:
+                f.write(inp.__pyml__())
+        return inp.__pyml__()
+    # else:
     if outp != '':
         with open(outp, "w+") as f:
             f.write(str(inp))
@@ -86,7 +93,14 @@ class tag(object):
     The class from which all html tags extend.
     """
 
-    # TODO - slots?.
+    __slots__ = [
+        "args",
+        "kwargs",
+        "__content",
+        "____attributes__",  # ? seems to work. but not sure if its correct
+    ]
+
+    __context: list = None  # private. tags will append to last item in context on creation.
 
     def __init__(self, *args, **kwargs):
         self.args = args
@@ -100,6 +114,10 @@ class tag(object):
         # except Exception as e:
             # print(e)
 
+        # if a context is open, add this tag to the context
+        if tag.__context is not None:
+            tag.__context[len(tag.__context) - 1] += self
+
     @property
     def content(self):  # TODO - test
         return ''.join([each.__str__() for each in self.args])
@@ -266,6 +284,26 @@ class tag(object):
 
         raise AttributeError
 
+    def __pyml__(self):
+        """ [returns a representation of the object as a pyml string] """
+        from domonic.dom import Text
+        params = ""
+        for key, value in self.kwargs.items():
+            params += f'{key}="{value}", '
+        # TODO - will need to loop args and call __pyml__ on each one
+        for arg in self.args:
+            try:
+                if isinstance(arg, Text):
+                    params += str(arg) + ", "
+                else:
+                    params += f"{arg.__pyml__()}, "
+            except Exception as e:
+                params += str(arg) + ", "
+        return f"{self.name}({params[:-2]})"
+        # return f"{self.name}({params})"
+        # return f"{self.name}({args}, {params})"
+        # return f"<{self.name}{self.__attributes__}>{self.content}</{self.name}>"
+
     # def __repr__(self):
     #     return f"<{self.name}{self.__attributes__}>{self.content}</{self.name}>"
 
@@ -273,9 +311,96 @@ class tag(object):
         # self.args[key] = value
         # print(self.args[key])
 
-    # def __enter__(self):
-    # def __exit__(self ,type, value, traceback):
-    # def __dir__/__getattr__/__getattribute)) - .... dot notation for attributes
+    def __enter__(self):
+        if tag.__context is None:
+            tag.__context = []
+        tag.__context.append(self)
+        return self
+
+    def __exit__(self, type, value, traceback, *args, **kwargs):
+        tag.__context.pop()
+        if len(tag.__context) == 0:
+            tag.__context = None
+        return self
+
+    # def __dir__(self):
+    #     return self.__dict__.keys()
+
+    # TODO - these are hard and wil need tests
+    # def __setattr__(self, attr, value):
+    # def __delattr__(self, attr):
+    # def __next__(self):
+    # def __iter__(self):
+
+    def __format__(self, format_spec):
+        # return super().__format__(format_spec)
+        # get node depth by counting parents
+
+        # TODO - this is a hack to get the depth of the node
+        n = self
+        depth = 0
+        while n is not None:
+            # print(type(n), type(n.parentNode))
+            n = n.parentNode
+            depth += 1
+
+        depth -= 1
+
+        # print(f"depth: {depth}")
+        dent = '    ' * depth
+
+        # loop the children and call __format__ on each one
+        # content = ""
+        # for child in self.childNodes:
+        #     content += child.__format__(format_spec)
+
+        self._update_parents()
+
+        content = ''.join([each.__format__(format_spec) for each in self.args])
+
+        wrap = False
+        if len(self.args) == 1:
+            if not isinstance(self.args[0], Element):
+                wrap = True
+
+        dtype = ""
+        if isinstance(self, Document):
+            # dtype = "<!DOCTYPE html>"
+            dtype = self.doctype
+
+        size = len(str(content))
+        if size < 150 and wrap:
+            return f"\n{dent}<{self.name}{self.__attributes__}>{content}</{self.name}>"
+        else:
+            return f"{dtype}\n{dent}<{self.name}{self.__attributes__}>{content}\n{dent}</{self.name}>"
+
+    # def __call__(self, *args, **kwargs):
+    #     """
+    #     allows for calling the object as a function
+    #     """
+    #     print('calling a tag')
+    #     print(args)
+    #     print(kwargs)
+    #     print(self.name)
+    #     print(self.args)
+    #     print(self.kwargs)
+    #     print(self.__attributes__)
+    #     print(self.content)
+    #     print(self.parentNode)
+    #     print(self.childNodes)
+    #     print(self.previousSibling)
+    #     print(self.nextSibling)
+    #     print(self.ownerDocument)
+    #     print(self.nodeValue)
+    #     print(self.nodeName)
+    #     print(self.nodeType)
+
+    # def write(self, path):
+    #     """
+    #     writes the html to a file
+    #     """
+    #     with open(path, 'w') as f:
+    #         f.write(self.__format__(''))
 
 
 class closed_tag(tag):
@@ -310,6 +435,7 @@ def Atag(self, *args, **kwargs):
     # print('Atag: ', args, kwargs)
     tag.__init__(self, *args, **kwargs)
     Element.__init__(self, *args, **kwargs)
+
     # TODO - fix BUG. this stops having no href on a tags
     if kwargs.get('_href', None) is not None:
         URL.__init__(self, url=kwargs['_href'])
@@ -475,6 +601,8 @@ picture = type('picture', (tag, Element), {'name': 'picture', '__init__': tag_in
 class doctype():
     """doctype
 
+    - this will be deprecated in the future to the one on the DOM
+
     Returns:
         str: <!DOCTYPE html>
     """
@@ -491,6 +619,8 @@ class doctype():
 class comment():
     """comment
 
+    - this will be deprecated in the future in favour of Comment on the DOM
+
     Args:
         content (str): Message to be rendered inside the comment tag
 
@@ -512,16 +642,20 @@ class comment():
 
 def create_element(name='custom_tag', *args, **kwargs):
     '''
-    If you must, a method for creating custom tags
+    A method for creating custom tags
+
     tag name needs to be set due to custom tags with hyphens can't be classnames.
     i.e. hypenated tags <some-custom-tag></some-custom-tag>
     '''
-    # TODO - check for existing elements first and return if available
+    # import sys
+    # current_module = sys.modules[__name__]
+    # checks if already exists
+    if name in html_tags:
+        # cl = globals()[name]
+        return globals()[name]()
 
+    # print('creating custom element')
     custom_tag = type('custom_tag', (tag, Element), {'name': name, '__init__': tag_init})
-    # t = tag(*args, **kwargs)  #  TODO - this is not an element.
-    t = custom_tag(*args, **kwargs)
-    t.name = name
-    return t
-    # new_tag = type('custom_tag', (tag, Element), {'name': name, '__init__': tag_init})
-    # return new_tag
+    new_tag = custom_tag(*args, **kwargs)
+    new_tag.name = name
+    return new_tag
